

*Felix Bittmann, 2021

*** Nach Schulform ***
preserve
collapse (mean) m=aspi_ideal (semean) se=aspi_ideal, by(wave gym)
gen ci_upper = m + 1.96 * se
gen ci_lower = m - 1.96 * se
label define wave 1 "5" 2 "6" 3 "7" 4 "8" 5 "9", modify
label values wave wave
list

twoway (connected m wave if gym == 1) (connected m wave if gym == 0) ///
	(rcap ci_lower ci_upper wave if gym == 1) ///
	(rcap ci_lower ci_upper wave if gym == 0) ///
	, legend(position(6) order(1 "Academic track" 2 "Non-Academic track")) ///
	xtitle("Grade") xlabel(,valuelabel) ytitle("Share") title("Share with aspirations for Abitur")
graph save "Output/Graphs/aspirations1", replace
graph export "Output/Graphs/aspirations1.png", replace as(png) width(1600)
restore
	

*** Nach Bildung der Eltern ***
preserve
collapse (mean) m=aspi_ideal (semean) se=aspi_ideal, by(wave pareduc)
gen ci_upper = m + 1.96 * se
gen ci_lower = m - 1.96 * se
label define wave 1 "5" 2 "6" 3 "7" 4 "8" 5 "9", modify
label values wave wave
list

twoway (connected m wave if pareduc == 2) ///
	(connected m wave if pareduc == 1) ///
	(connected m wave if pareduc == 0) ///
	(rcap ci_lower ci_upper wave if pareduc == 0) ///
	(rcap ci_lower ci_upper wave if pareduc == 1) ///
	(rcap ci_lower ci_upper wave if pareduc == 2) ///
	, legend(position(6) order(1 "Higher education" ///
		2 "Upper secondary education" 3 "Less than upper secondary education")) ///
	xtitle("Grade") xlabel(,valuelabel) ytitle("Share") title("Share with aspirations for Abitur")
graph save "Output/Graphs/aspirations2", replace
graph export "Output/Graphs/aspirations2.png", replace as(png) width(1600)
restore
	
	

*** Nach Bildung der Eltern und Track ***
preserve
drop if missing(highedu)	
collapse (mean) m=aspi_ideal (semean) se=aspi_ideal, by(wave gym highedu)
gen ci_upper = m + 1.96 * se
gen ci_lower = m - 1.96 * se
label define wave 1 "5" 2 "6" 3 "7" 4 "8" 5 "9", modify
label values wave wave
list

twoway (connected m wave if gym == 1 & highedu == 1) ///
	(connected m wave if gym == 1 & highedu == 0) ///
	(connected m wave if gym == 0 & highedu == 1) ///
	(connected m wave if gym == 0 & highedu == 0) ///
	(rcap ci_lower ci_upper wave if gym == 0 & highedu == 0) ///
	(rcap ci_lower ci_upper wave if gym == 1 & highedu == 0) ///
	(rcap ci_lower ci_upper wave if gym == 0 & highedu == 1) ///
	(rcap ci_lower ci_upper wave if gym == 1 & highedu == 1) ///
	, legend(position(6) order(1 "High educ. / Academic" 2 "Low educ. / Academic" ///
		3 "High educ. / Non-academic" 4 "Low educ. / Non-academic")) ///
	xtitle("Grade") xlabel(,valuelabel) ytitle("Share") title("Share with aspirations for Abitur")
graph save "Output/Graphs/aspirations3", replace
graph export "Output/Graphs/aspirations3.png", replace as(png) width(1600)
restore


********************************************************************************
*** Realistic aspirations ***
********************************************************************************
tempfile a
save `a', replace

quiet do "Dos/Opera.do
keep if inlist(wave, 1, 2, 3, 4, 5)		//Wellen 1-5 behalten
drop if missing(gym)					//falsche Schulformen raus
drop if wave == 1 & tx80220 > 1			//Nichtteilnehmer raus
count if wave == 1

*Nur Leute, die in Welle 1 ueber der Medianleistung liegen*
sum leistung if wave == 1, det
gen temp1 = 1 if wave == 1 & leistung >= `r(p50)' & !missing(leistung)
replace temp1 = 0 if missing(temp1)
bysort ID_t: egen temp2 = max(temp1)
keep if temp2 == 1
drop temp1 temp2
count if wave == 1


*Nur Leute, die in Welle 1 hohe Aspirationen haben*
gen temp1 = aspi_real if wave == 1
bysort ID_t: egen temp2 = max(temp1)
keep if temp2 == 1
drop temp1 temp2
count if wave == 1


keep if alleteilnahmen == 1				//Teilnehmer in W1, W2 und W5
count if wave == 1
keep if sameschool == 1					//Immer gleicher Schultyp W1, W2 und W5
count if wave == 1
drop if missing(gym)					//Schulform immer bekannt
count if wave == 1


*Listwise deletion*
egen temp = rowmiss(gym female pareduc alter2011 leistung osten zusammenleben ///
	migration aspi_real mean_* math read score5 speed5) if wave == 1
fre temp
bysort ID_t: egen nmiss = max(temp)
drop temp
keep if nmiss == 0
count if wave == 1

bysort ID_t (wave): gen temp = 1 if wave == 1 & !missing(aspi_real) & ///
	!missing(aspi_real[_n+1]) & !missing(aspi_real[_n+4])
bysort ID_t: egen complete = max(temp)
drop temp
keep if complete == 1
count if wave == 1
bysort ID_t: egen ID_i2 = mode(ID_i), minmode		//Add missing school IDs

*** Nach Schulform ***
preserve
collapse (mean) m=aspi_real (semean) se=aspi_real, by(wave gym)
gen ci_upper = m + 1.96 * se
gen ci_lower = m - 1.96 * se
label define wave 1 "5" 2 "6" 3 "7" 4 "8" 5 "9", modify
label values wave wave

twoway (connected m wave if gym == 1) (connected m wave if gym == 0) ///
	(rcap ci_lower ci_upper wave if gym == 1) ///
	(rcap ci_lower ci_upper wave if gym == 0) ///
	, legend(position(6) order(1 "Academic track" 2 "Non-Academic track")) ///
	xtitle("Grade") ytitle("Share") xlabel(,valuelabel) title("Share with realistic aspirations for Abitur")
graph save "Output/Graphs/aspirations_real1", replace
graph export "Output/Graphs/aspirations_real1.png", replace as(png) width(1600)
restore

preserve
collapse (mean) m=aspi_real (semean) se=aspi_real, by(wave pareduc)
gen ci_upper = m + 1.96 * se
gen ci_lower = m - 1.96 * se
label define wave 1 "5" 2 "6" 3 "7" 4 "8" 5 "9", modify
label values wave wave

twoway (connected m wave if pareduc == 2) ///
	(connected m wave if pareduc == 1) ///
	(connected m wave if pareduc == 0) ///
	(rcap ci_lower ci_upper wave if pareduc == 0) ///
	(rcap ci_lower ci_upper wave if pareduc == 1) ///
	(rcap ci_lower ci_upper wave if pareduc == 2) ///
	, legend(position(6) order(1 "Higher education" ///
		2 "Upper secondary education" 3 "Less than upper secondary education")) ///
	xtitle("Grade") ytitle("Share") xlabel(,valuelabel) title("Share with realistic aspirations for Abitur")
graph save "Output/Graphs/aspirations_real2", replace
graph export "Output/Graphs/aspirations_real2.png", replace as(png) width(1600)
restore




use `a', clear		//Reload
